SectionInfo class

Section information for pubspec parsing

Constructors

SectionInfo({required String name, required int startIndex, required int endIndex})

Properties

endIndex int
End line index
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
Section name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startIndex int
Start line index
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited