GroupedDependencies class

Grouped dependencies data structure

Constructors

GroupedDependencies({required Map<String, List<DependencyInfo>> grouped, required List<String> categoryOrder})
Creates grouped dependencies
const

Properties

categoryCount → int
Get number of categories
no setter
categoryOrder → List<String>
Order of categories
final
grouped → Map<String, List<DependencyInfo>>
Dependencies grouped by category
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalPackages → int
Get total number of packages
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited