PackageSuggestion class

Package suggestion data structure

Constructors

PackageSuggestion({required String packageName, required List<String> categories, String? notes})
Creates a package suggestion
const

Properties

categories List<String>
Suggested categories
final
hashCode int
The hash code for this object.
no setterinherited
notes String?
Optional notes
final
packageName String
Package name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited