ApiService class

Service for fetching package data from SmartPub Worker API

Constructors

ApiService({String baseUrl = 'https://smartpub-worker.smartpub.workers.dev'})
Creates an API service
const

Properties

baseUrl String
Base URL for the API
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchPackage(String packageName) Future<PackageCategory?>
Fetch category for a single package
fetchPackages(List<String> packageNames) Future<List<PackageCategory>>
Fetch categories for multiple packages
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited