PackageCategorizer class

Categorizes packages using: local cache → API.

Constructors

PackageCategorizer({required CacheService cacheService, required ApiService apiService})
Creates a package categorizer

Properties

apiService ApiService
API service
final
cacheService CacheService
Local cache service
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

classifyPackage(String packageName) Future<String>
Classify a package and return its primary category Order: local cache → API
clearCache() Future<void>
Clear the local cache
getPackageCategories(String packageName) Future<List<String>>
Get all categories for a package Order: local cache → API
initialize() Future<void>
Initialize the categorizer (load local cache)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited