SuggestionService class

Service for submitting package categorization suggestions

Constructors

SuggestionService({String apiEndpoint = 'https://smartpub-api.example.com'})

Properties

apiEndpoint → String
API endpoint for suggestions
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
submitBatchSuggestions(List<PackageSuggestion> suggestions) → Future<int>
Submit multiple suggestions in batch
submitSuggestion({required String packageName, required List<String> categories, String? notes}) → Future<bool>
Submit a package categorization suggestion
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited