CategorizationConfig class

Categorization configuration and defaults

Constructors

CategorizationConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

cacheFileName → const String
cacheTtlDays → const int
userCacheDirectory → const String
Cache configuration - uses user-level cache directory