toolError constant
int
const toolError
Tool error — missing pubspec.yaml, no backup exists, parse failure, or any unrecoverable internal error.
Implementation
static const int toolError = 2;
Tool error — missing pubspec.yaml, no backup exists, parse failure, or any unrecoverable internal error.
static const int toolError = 2;