DependencyInfo class

Information about a single dependency

Constructors

DependencyInfo({required String name, required String version, required DependencySection section, required DependencyStatus status, required bool usedInLib, required bool usedInTest, required bool usedInBin, required bool usedInTool})

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Package name
final
needsAction → bool
Whether this dependency needs action
no setter
recommendation → String
Get recommendation for this dependency
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
section → DependencySection
Which section it's currently in (dependencies or dev_dependencies)
final
status → DependencyStatus
Current usage status
final
usageDescription → String
Get usage description
no setter
usedInBin → bool
Whether it's used in bin/ directory
final
usedInLib → bool
Whether it's used in lib/ directory
final
usedInTest → bool
Whether it's used in test/ directory
final
usedInTool → bool
Whether it's used in tool/ directory
final
version → String
Package version
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited