MissingDependency class

Information about a missing dependency (imported/exported in code but not declared in pubspec.yaml)

Constructors

MissingDependency({required String name, required bool usedInLib, required bool usedInTest, required bool usedInBin, required bool usedInTool})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Package name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usageDescription String
Get usage description
no setter
usedInBin bool
Whether it's used in bin/ directory
final
usedInLib bool
Whether it's used in lib/ directory
final
usedInTest bool
Whether it's used in test/ directory
final
usedInTool bool
Whether it's used in tool/ directory
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited