SmartpubChecksConfig class

Configuration for SmartPub checks selection

Constructors

SmartpubChecksConfig({bool unused = true, bool missing = true, bool promotions = true})
const
SmartpubChecksConfig.fromJson(Map json)
Parse from json Map
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
missing → bool
Check for missing dependencies
final
promotions → bool
Check for misplaced dependencies
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unused → bool
Check for unused dependencies
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited