BackupRestoreResult class

Result returned by BackupService.restoreFromBackup

Constructors

BackupRestoreResult(RestoreStatus status, [String? message])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
no setter
message String?
Human-readable description (populated for RestoreStatus.noBackup and RestoreStatus.ioError).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status RestoreStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited