UpdateInfo class

Information about available updates

Constructors

UpdateInfo({required String currentVersion, required String latestVersion, required bool hasUpdate, required DateTime lastChecked, String? error})
UpdateInfo.fromJson(Map<String, dynamic> json)
Create UpdateInfo from JSON
factory

Properties

currentVersion String
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
hasUpdate bool
final
isSuccessful bool
Whether the check was successful
no setter
lastChecked DateTime
final
latestVersion String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateMessage String
Get formatted update message
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert UpdateInfo to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited