services/services library
SmartPub Services
This library exports all service classes for SmartPub including backup, pubspec management, apply operations, and update checking.
Classes
- ApplyResult
- Result of applying dependency changes
- ApplyService
- Service for applying dependency fixes
- BackupInfo
- Information about a backup file
- BackupService
- Service for managing pubspec.yaml backups
- DependencyChange
- Represents a change to be made to dependencies
- PubspecData
- Data structure for pubspec content
- PubspecManager
- Manager for pubspec.yaml file operations
- UpdateChecker
- Service for checking and managing SmartPub updates
- UpdateInfo
- Information about available updates
Enums
- ChangeAction
- Types of changes that can be made to dependencies