ui/interactive_grouping_service library
Interactive Grouping Service
Handles interactive category overrides and user input for package grouping.
Classes
- InteractiveGroupingService
- Service for interactive package categorization
Interactive Grouping Service
Handles interactive category overrides and user input for package grouping.