InteractiveGroupingService class

Service for interactive package categorization

Constructors

InteractiveGroupingService({required GemsIntegration gemsIntegration})

Properties

gemsIntegration GemsIntegration
Gems integration service
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
promptForOverrides(List<DependencyInfo> dependencies) Future<Map<String, String>>
Prompt user for category overrides
showAvailableCategories() → void
Show available categories for reference
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

promptYesNo(String question, {bool defaultValue = false}) bool
Prompt yes/no question