MultiStepSpinner class

Multi-step spinner — shows "Step 1/3: Fetching...", "Step 2/3: ..."

Constructors

MultiStepSpinner(List<String> steps)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(List<Future<void> Function()> tasks) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited