GemsIntegration class
Package categorization using API with local cache
Constructors
- GemsIntegration()
- Creates a new GemsIntegration instance
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
classifyPackage(
String packageName) → Future< String> - Classify a package and return its primary category Retrieval order: local cache → API
-
getPackageCategories(
String packageName) → Future< List< String> > - Get all categories for a package Retrieval order: local cache → API
-
initialize(
) → Future< void> - Initialize the integration service (load local cache)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- cacheFilePath → String
-
Get cache file path for external access
no setter
Static Methods
-
clearCache(
) → Future< void> - Clear the user cache file