GroupingService class
Service for grouping dependencies by categories
Constructors
-
GroupingService({required GemsIntegration gemsIntegration, Map<
String, String> ? groupOverrides})
Properties
- gemsIntegration → GemsIntegration
-
Gems integration service
final
-
groupOverrides
→ Map<
String, String> ? -
Local overrides for package categories
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateGroupedPubspec(
GroupedDependencies groupedDeps, GroupedDependencies groupedDevDeps) → Future< String> - Generate grouped pubspec.yaml content
-
generatePreview(
GroupedDependencies groupedDeps, GroupedDependencies groupedDevDeps) → String - Generate preview of grouped dependencies
-
groupDependencies(
List< DependencyInfo> dependencies) → Future<GroupedDependencies> - Group dependencies by categories
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited