PackageCategory class

Package category information

Constructors

PackageCategory({required String name, required List<String> categories, required String primaryCategory, required String source, required double confidence, required DateTime fetchedAt})
Creates a package category
const
PackageCategory.fromJson(Map<String, dynamic> json)
Create from JSON
factory

Properties

categories List<String>
All categories for this package
final
confidence double
Confidence score (0.0 to 1.0)
final
fetchedAt DateTime
When this data was fetched
final
hashCode int
The hash code for this object.
no setterinherited
name String
Package name
final
primaryCategory String
Primary category
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
Source of the data (firestore, fluttergems, heuristic)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON for caching
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited