CacheService class

Service for managing local package category cache

Constructors

CacheService()

Properties

hashCode int
The hash code for this object.
no setterinherited
keys List<String>
All cached package names (for refresh-from-remote flows)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clear the cache
get(String packageName) PackageCategory?
Get package from cache
initialize() Future<void>
Initialize cache
isValid(PackageCategory category) bool
Check if cache entry is valid
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(String packageName, PackageCategory category) Future<void>
Save package to cache
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

cacheFilePath String
Get cache file path
no setter