AppConfig class

Application information and metadata

Constructors

AppConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fullTitle String
Full application title
no setter
version String
Current version of the application (loaded from pubspec.yaml)
no setter

Static Methods

initialize() Future<void>
Initialize the version from pubspec.yaml

Constants

appName → const String
Application name
description → const String
Application description
repositoryUrl → const String
Repository URL
tagline → const String
Application tagline