SmartpubConfig class
Main configuration model for smartpub.yaml
Constructors
-
SmartpubConfig({List<
String> ignore = const <String>[], List<String> exclude = const <String>[], bool allowPins = false, bool failOnViolations = true, SmartpubChecksConfig checks = const SmartpubChecksConfig()}) -
const
- SmartpubConfig.fromJson(Map json)
-
Parse from json Map
factory
Properties
- allowPins → bool
-
Whether to allow version pins without warnings
final
- checks → SmartpubChecksConfig
-
Selection of checks to run
final
-
exclude
→ List<
String> -
Directories/files to exclude from import scanning
final
- failOnViolations → bool
-
Whether to exit non-zero when violations exist
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ignore
→ List<
String> -
Dependencies to never flag as unused or misplaced
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
String projectPath, {String? configPath}) → SmartpubConfig - Load config from file, fall back to defaults