TelemetryService class
Service for collecting anonymous usage telemetry
Constructors
- TelemetryService({bool enabled = true, String apiEndpoint = 'https://smartpub-telemetry.example.com'})
Properties
- apiEndpoint → String
-
Telemetry API endpoint
final
- enabled → bool
-
Whether telemetry is enabled
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordCategorizationUsage(
{required int totalPackages, required int categorizedPackages, required int cacheHits, required int firestoreHits, required int fallbackHits, required int heuristicHits, required int overrideCount}) → Future< void> - Record categorization usage
-
recordUsage(
{required String command, required int dependencyCount, required int issuesFound, required bool applied}) → Future< void> - Record general usage statistics
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited