Spinner class
Constructors
- Spinner({required String label, SpinnerStyle style = SpinnerStyle.braille, Duration interval = const Duration(milliseconds: 80)})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → SpinnerStyle
-
final
Methods
-
fail(
[String? message]) → void - Call this when the task fails.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → void -
success(
[String? message]) → void - Call this when the task succeeds.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
String newLabel) → void - Update the label mid-spin (e.g. "Fetching... 3/12 packages").
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited